==> image-saas-client-0.0.160-sources.jar: com/xforceplus/imagesaas/controller/TicketBusFeignApi.java <==
package com.xforceplus.imagesaas.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2021-07-05
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.imagesaas.entity.TicketBus;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "image-saas")
public interface TicketBusFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/ticketBus/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param ticketBus ${table.comment}
   * @return R
   */
  @PostMapping("/ticketBus/add")
  public R save(@RequestBody TicketBus ticketBus);

  /**
   * 修改${table.comment}
   * @param ticketBus ${table.comment}
   * @return R
   */
  @PostMapping("/ticketBus/update")
  public R updateById(@RequestBody TicketBus ticketBus);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/ticketBus/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> image-saas-client-0.1.193-sources.jar: com/xforceplus/imagesaas/controller/TicketBusFeignApi.java <==
package com.xforceplus.imagesaas.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2023-05-12
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.imagesaas.entity.TicketBus;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "image-saas")
public interface TicketBusFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/ticketBus/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param ticketBus ${table.comment}
   * @return R
   */
  @PostMapping("/ticketBus/add")
  public R save(@RequestBody TicketBus ticketBus);

  /**
   * 修改${table.comment}
   * @param ticketBus ${table.comment}
   * @return R
   */
  @PostMapping("/ticketBus/update")
  public R updateById(@RequestBody TicketBus ticketBus);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/ticketBus/del/{id}" )
  public R removeById(@PathVariable Long id);

}
